# To display an informative message when the package loads:
#  - to make usage conditions clear
#  - to display useful tips

.onAttach <- function(libname, pkgname) {
  packageStartupMessage("Welcome to the MNREAD R package!
                        v2.0.0 now includes NLME estimation of the MRS and CPS :-)")
}


# To set custom options for the package
.onLoad <- function(libname, pkgname) {
  op <- options()
  op.devtools <- list(
    devtools.path = "~/R-dev",
    devtools.install.args = "",
    devtools.name = "mnreadR",
    devtools.desc.author = '"Aurelie Calabrese <acalabre@umn.edu> [aut, cre]"',
    devtools.desc.license = "What license is it under?",
    devtools.desc.suggests = NULL,
    devtools.desc = list()
  )
  toset <- !(names(op.devtools) %in% names(op))
  if(any(toset)) options(op.devtools[toset])
  invisible()
}


